@@ -24,6 +24,7 @@ class DCCA_NOI(DCCA):
         rho: float = 0.2,
         eps: float = 1e-9,
         shared_target: bool = False,
+        **kwargs,
     ):
         """
         Constructor class for DCCA
@@ -36,7 +37,9 @@ class DCCA_NOI(DCCA):
         :param eps: epsilon used throughout
         :param shared_target: not used
         """
-        super().__init__(latent_dims=latent_dims, encoders=encoders, r=r, eps=eps)
+        super().__init__(
+            latent_dims=latent_dims, encoders=encoders, r=r, eps=eps, **kwargs
+        )
         self.N = N
         self.covs = None
         if rho < 0 or rho > 1:
@@ -54,7 +57,7 @@ class DCCA_NOI(DCCA):
         )
         self.rand = torch.rand(N, self.latent_dims)
 
-    def forward(self, *args):
+    def forward(self, *args, **kwargs):
         z = []
         # Users architecture + final linear layer
         for i, (encoder, linear_layer) in enumerate(
@@ -66,10 +69,11 @@ class DCCA_NOI(DCCA):
     def loss(self, *args):
         z = self(*args)
         z_copy = [z_.detach().clone() for z_ in z]
-        self._update_covariances(*z_copy)
+        self._update_covariances(*z_copy, train=self.training)
         covariance_inv = [mat_pow(cov, -0.5, self.eps) for cov in self.covs]
         preds = [z_ @ covariance_inv[i] for i, z_ in enumerate(z_copy)]
         loss = self.mse(z[0], preds[1]) + self.mse(z[1], preds[0])
+        self.covs = [cov.detach() for cov in self.covs]
         return {"objective": loss}
 
     def _update_covariances(self, *z, train=True):
@@ -83,3 +87,6 @@ class DCCA_NOI(DCCA):
                 ]
             else:
                 self.covs = batch_covs
+        # pytorch-lightning runs validation once so this just fixes the bug
+        elif self.covs is None:
+            self.covs = batch_covs
