@@ -1,11 +1,13 @@
 from typing import Iterable
 
 import torch
-import torch.distributions as dist
+import torchvision
+from torch.autograd import Variable
 from torch.nn import functional as F
 
-from cca_zoo.deepmodels.architectures import BaseEncoder, Encoder, Decoder
+from cca_zoo.deepmodels.architectures import BaseEncoder
 from cca_zoo.deepmodels.dcca import _DCCA_base
+import matplotlib.pyplot as plt
 
 
 class DVCCA(_DCCA_base):
@@ -28,6 +30,10 @@ class DVCCA(_DCCA_base):
         encoders=None,
         decoders=None,
         private_encoders: Iterable[BaseEncoder] = None,
+        latent_dropout=0,
+        log_images=True,
+        img_dim=(1, 28, 28),
+        **kwargs,
     ):
         """
         :param latent_dims: # latent dimensions
@@ -35,11 +41,10 @@ class DVCCA(_DCCA_base):
         :param decoders:  list of decoder networks
         :param private_encoders: list of private (view specific) encoder networks
         """
-        super().__init__(latent_dims=latent_dims)
-        if decoders is None:
-            decoders = [Decoder, Decoder]
-        if encoders is None:
-            encoders = [Encoder, Encoder]
+        super().__init__(latent_dims=latent_dims, **kwargs)
+        self.log_images = log_images
+        self.img_dim = img_dim
+        self.latent_dropout = torch.nn.Dropout(p=latent_dropout)
         self.encoders = torch.nn.ModuleList(encoders)
         self.decoders = torch.nn.ModuleList(decoders)
         if private_encoders:
@@ -47,7 +52,7 @@ class DVCCA(_DCCA_base):
         else:
             self.private_encoders = None
 
-    def forward(self, *args, mle=True):
+    def forward(self, *args, mle=True, **kwargs):
         """
         :param args:
         :param mle:
@@ -59,12 +64,12 @@ class DVCCA(_DCCA_base):
         # Used when we get reconstructions
         mu["shared"], logvar["shared"] = self._encode(*args)
         z["shared"] = self._sample(mu["shared"], logvar["shared"], mle)
-        # If using single encoder repeat representation n times
-        if len(self.encoders) == 1:
-            z["shared"] = z["shared"] * len(args)
         if self.private_encoders:
             mu["private"], logvar["private"] = self._encode_private(*args)
-            z["private"] = self._sample(mu["private"], logvar["private"], mle)
+            z["private"] = [
+                self._sample(mu_, logvar_, mle)
+                for mu_, logvar_ in zip(mu["private"], logvar["private"])
+            ]
         return z, mu, logvar
 
     def _sample(self, mu, logvar, mle):
@@ -78,10 +83,7 @@ class DVCCA(_DCCA_base):
         if mle:
             return mu
         else:
-            return [
-                dist.Normal(mu_, torch.exp(0.5 * logvar_)).rsample()
-                for mu_, logvar_ in zip(mu, logvar)
-            ]
+            return mu + torch.randn_like(logvar) * torch.exp(0.5 * logvar)
 
     def _encode(self, *args):
         """
@@ -94,7 +96,7 @@ class DVCCA(_DCCA_base):
             mu_i, logvar_i = encoder(args[i])
             mu.append(mu_i)
             logvar.append(logvar_i)
-        return mu, logvar
+        return torch.stack(mu).sum(dim=0), torch.stack(logvar).sum(dim=0)
 
     def _encode_private(self, *args):
         """
@@ -117,53 +119,73 @@ class DVCCA(_DCCA_base):
         x = []
         for i, decoder in enumerate(self.decoders):
             if "private" in z:
-                x_i = F.sigmoid(
-                    decoder(torch.cat((z["shared"][i], z["private"][i]), dim=-1))
+                x_i = decoder(
+                    torch.cat(
+                        (
+                            z["shared"],
+                            z["private"][i],
+                        ),
+                        dim=-1,
+                    )
                 )
             else:
-                x_i = F.sigmoid(decoder(z["shared"][i]))
+                x_i = decoder(z["shared"])
             x.append(x_i)
         return x
 
-    def recon(self, *args, mle=True):
-        """
-        :param args:
-        :return:
-        """
-        z, _, _ = self(*args, mle=mle)
-        return self._decode(z)
-
     def loss(self, *args):
         """
         :param args:
         :return:
         """
         z, mu, logvar = self(*args, mle=False)
+        recons = self._decode(z)
         loss = dict()
-        loss["reconstruction"] = self.recon_loss(args, z)
-        loss["kl shared"] = self.kl_loss(mu["shared"], logvar["shared"])
+        loss["reconstruction"] = torch.stack(
+            [self.recon_loss(x, recon) for x, recon in zip(args, recons)]
+        ).sum()
+        loss["kl shared"] = (
+            self.kl_loss(mu["shared"], logvar["shared"]) / args[0].numel()
+        )
         if "private" in z:
-            loss["kl private"] = self.kl_loss(mu["private"], logvar["private"])
+            loss["kl private"] = torch.stack(
+                [
+                    self.kl_loss(mu_, logvar_) / args[0].numel()
+                    for mu_, logvar_ in zip(mu["private"], logvar["private"])
+                ]
+            ).sum()
         loss["objective"] = torch.stack(tuple(loss.values())).sum()
         return loss
 
     @staticmethod
     def kl_loss(mu, logvar):
-        return torch.stack(
-            [
-                torch.mean(
-                    -0.5 * torch.sum(1 + logvar_ - logvar_.exp() - mu_.pow(2), dim=1),
-                    dim=0,
-                )
-                for mu_, logvar_ in zip(mu, logvar)
-            ]
-        ).sum()
+        return -0.5 * torch.sum(1 + logvar - mu.pow(2) - logvar.exp())
 
-    def recon_loss(self, x, z):
-        recon = self._decode(z)
-        return torch.stack(
-            [
-                F.binary_cross_entropy(recon, arg, reduction="mean")
-                for recon, arg in zip(recon, x)
-            ]
-        ).sum()
+    def recon_loss(self, x, recon):
+        return F.mse_loss(recon, x, reduction="mean")
+
+    def on_validation_epoch_end(self) -> None:
+        if self.log_images:
+            z = dict()
+            z["shared"] = Variable(torch.randn(64, self.latent_dims))
+            if self.private_encoders:
+                z["private"] = [Variable(torch.randn(64, self.latent_dims))] * len(
+                    self.private_encoders
+                )
+            sample = self._decode(z)
+            sample[0] = torch.reshape(sample[0], (64,) + self.img_dim)
+            sample[1] = torch.reshape(sample[1], (64,) + self.img_dim)
+            grid1 = torchvision.utils.make_grid(sample[0])
+            grid2 = torchvision.utils.make_grid(sample[1])
+            self.logger.experiment.add_image(
+                "generated_images_1", grid1, self.current_epoch
+            )
+            self.logger.experiment.add_image(
+                "generated_images_2", grid2, self.current_epoch
+            )
+
+    def plot_latent_label(self, loader: torch.utils.data.DataLoader):
+        fig, ax = plt.subplots(ncols=1)
+        for i, batch in enumerate(loader):
+            z = self(*batch["views"])[0]["shared"].cpu().detach().numpy()
+            im = ax.scatter(z[:, 0], z[:, 1], c=batch["label"].numpy(), cmap="tab10")
