@@ -92,7 +92,7 @@ class NCCA(_CCA_Base):
         self.S = S[1 : self.latent_dims + 1]
         return self
 
-    def transform(self, views: Iterable[np.ndarray], y=None, **kwargs):
+    def transform(self, views: Iterable[np.ndarray], **kwargs):
         """
         Transforms data given a fit model
 
