@@ -11,10 +11,9 @@ from matplotlib import pyplot as plt
 from torch.utils.data import Subset
 
 # %%
-from multiviewdata.torchdatasets import SplitMNISTDataset
+from multiviewdata.torchdatasets import SplitMNIST
 from cca_zoo.deepmodels import (
     DCCA,
-    CCALightning,
     get_dataloaders,
     architectures,
     DCCA_NOI,
@@ -22,31 +21,12 @@ from cca_zoo.deepmodels import (
     BarlowTwins,
 )
 
-
-def plot_latent_label(model, dataloader, num_batches=100):
-    fig, ax = plt.subplots(ncols=model.latent_dims)
-    for j in range(model.latent_dims):
-        ax[j].set_title(f"Dimension {j}")
-        ax[j].set_xlabel("View 1")
-        ax[j].set_ylabel("View 2")
-    for i, batch in enumerate(dataloader):
-        z = model(*batch["views"])
-        zx, zy = z
-        zx = zx.to("cpu").detach().numpy()
-        zy = zy.to("cpu").detach().numpy()
-        for j in range(model.latent_dims):
-            ax[j].scatter(zx[:, j], zy[:, j], c=batch["label"].numpy(), cmap="tab10")
-        if i > num_batches:
-            plt.colorbar()
-            break
-
-
 n_train = 500
 n_val = 100
-train_dataset = SplitMNISTDataset(root="",mnist_type="MNIST", train=True, download=True)
+train_dataset = SplitMNIST(root="", mnist_type="MNIST", train=True, download=True)
 val_dataset = Subset(train_dataset, np.arange(n_train, n_train + n_val))
 train_dataset = Subset(train_dataset, np.arange(n_train))
-train_loader, val_loader = get_dataloaders(train_dataset, val_dataset, batch_size=128)
+train_loader, val_loader = get_dataloaders(train_dataset, val_dataset, batch_size=50)
 
 # The number of latent dimensions across models
 latent_dims = 2
@@ -59,7 +39,6 @@ encoder_2 = architectures.Encoder(latent_dims=latent_dims, feature_size=392)
 # %%
 # Deep CCA
 dcca = DCCA(latent_dims=latent_dims, encoders=[encoder_1, encoder_2])
-dcca = CCALightning(dcca)
 trainer = pl.Trainer(
     max_epochs=epochs,
     enable_checkpointing=False,
@@ -67,7 +46,7 @@ trainer = pl.Trainer(
     flush_logs_every_n_steps=1,
 )
 trainer.fit(dcca, train_loader, val_loader)
-plot_latent_label(dcca.model, train_loader)
+dcca.plot_latent_label(train_loader)
 plt.suptitle("DCCA")
 plt.show()
 
@@ -76,7 +55,6 @@ plt.show()
 dcca_noi = DCCA_NOI(
     latent_dims=latent_dims, N=len(train_dataset), encoders=[encoder_1, encoder_2]
 )
-dcca_noi = CCALightning(dcca_noi)
 trainer = pl.Trainer(
     max_epochs=epochs,
     enable_checkpointing=False,
@@ -84,7 +62,7 @@ trainer = pl.Trainer(
     flush_logs_every_n_steps=1,
 )
 trainer.fit(dcca_noi, train_loader, val_loader)
-plot_latent_label(dcca_noi.model, train_loader)
+dcca_noi.plot_latent_label(train_loader)
 plt.suptitle("DCCA by Non-Linear Orthogonal Iterations")
 plt.show()
 
@@ -93,7 +71,6 @@ plt.show()
 dcca_sdl = DCCA_SDL(
     latent_dims=latent_dims, N=len(train_dataset), encoders=[encoder_1, encoder_2]
 )
-dcca_sdl = CCALightning(dcca_sdl)
 trainer = pl.Trainer(
     max_epochs=epochs,
     enable_checkpointing=False,
@@ -101,14 +78,13 @@ trainer = pl.Trainer(
     flush_logs_every_n_steps=1,
 )
 trainer.fit(dcca_sdl, train_loader, val_loader)
-plot_latent_label(dcca_sdl.model, train_loader)
+dcca_sdl.plot_latent_label(train_loader)
 plt.suptitle("DCCA by Stochastic Decorrelation")
 plt.show()
 
 # %%
 # Deep CCA by Barlow Twins
 barlowtwins = BarlowTwins(latent_dims=latent_dims, encoders=[encoder_1, encoder_2])
-barlowtwins = CCALightning(barlowtwins)
 trainer = pl.Trainer(
     max_epochs=epochs,
     enable_checkpointing=False,
@@ -116,6 +92,6 @@ trainer = pl.Trainer(
     flush_logs_every_n_steps=1,
 )
 trainer.fit(barlowtwins, train_loader, val_loader)
-plot_latent_label(barlowtwins.model, train_loader)
+barlowtwins.plot_latent_label(train_loader)
 plt.suptitle("DCCA by Barlow Twins")
 plt.show()
